@@ -34,10 +34,10 @@ setMethod("Arith", signature(e1='RasterLayer', e2='RasterLayer'),
 			pb <- pbCreate(tr$n, type=.progress())			
 			r <- writeStart(r, filename=rasterTmpFile(), overwrite=TRUE )
 			for (i in 1:tr$n) {
-				v1 <- getValuesBlock(e1, row=tr$row[i], nrows=tr$size)
-				v2 <- getValuesBlock(e2, row=tr$row[i], nrows=tr$size)
+				v1 <- getValues(e1, row=tr$row[i], nrows=tr$size)
+				v2 <- getValues(e2, row=tr$row[i], nrows=tr$size)
 				v <- callGeneric( v1, v2 )
-				writeValues(r, v, tr$row[i])
+				r <- writeValues(r, v, tr$row[i])
 				pbStep(pb, i) 	
 			}
 			r <- writeStop(r)
@@ -59,9 +59,9 @@ setMethod("Arith", signature(e1='RasterLayer', e2='numeric'),
 			pb <- pbCreate(tr$n, type=.progress())			
 			r <- writeStart(r, filename=rasterTmpFile(), format=.filetype(), overwrite=TRUE )
 			for (i in 1:tr$n) {
-				v <- getValuesBlock(e1, row=tr$row[i], nrows=tr$size)
+				v <- getValues(e1, row=tr$row[i], nrows=tr$size)
 				v <- callGeneric( v, e2 )
-				writeValues(r, v, tr$row[i])
+				r <- writeValues(r, v, tr$row[i])
 				pbStep(pb, i) 	
 			}
 			r <- writeStop(r)
@@ -85,9 +85,9 @@ setMethod("Arith", signature(e1='numeric', e2='RasterLayer'),
 			pb <- pbCreate(tr$n, type=.progress())			
 			r <- writeStart(r, filename=rasterTmpFile(), format=.filetype(), overwrite=TRUE )
 			for (i in 1:tr$n) {
-				v <- getValuesBlock(e2, row=tr$row[i], nrows=tr$size)
+				v <- getValues(e2, row=tr$row[i], nrows=tr$size)
 				v <- callGeneric( v, e1 )
-				writeValues(r, v, tr$row[i])
+				r <- writeValues(r, v, tr$row[i])
 				pbStep(pb, i) 	
 			}
 			r <- writeStop(r)
@@ -110,8 +110,8 @@ setMethod("Arith", signature(e1='RasterBrick', e2='numeric'),
 			pb <- pbCreate(tr$n, type=.progress())
 			b <- writeStart(b, filename=filename, bandorder='BIL')
 			for (i in 1:tr$n) {
-				v <- getValuesBlock(e1, row=tr$row[i], nrows=tr$size)
-				writeValues(b, v, tr$row[i])
+				v <- getValues(e1, row=tr$row[i], nrows=tr$size)
+				b <- writeValues(b, v, tr$row[i])
 				pbStep(pb, i)
 			}
 			pbClose(pb)
