@@ -5,10 +5,12 @@
 
 
 .clearRaster <- function(object) {
-	object@data@content <- 'nodata'
-	object@data@indices = vector(mode='numeric')
+	object@data@inmemory <- FALSE
+	
+	
+#	object@data@indices = vector(mode='numeric')
 	object@data@values <- vector()
-	if (dataSource(object) == 'ram') {
+	if ( !  fromDisk(object) ) {
 		object@data@min <- Inf
 		object@data@max <- -Inf	
 		object@data@haveminmax <- FALSE
@@ -24,15 +26,16 @@ clearValues <- function(object) {
 		object <- .clearRaster(object)
 	} else if (class(object) == "RasterStack" ) {
 		for (i in seq(along=nlayers(object))) {
-			if (dataSource(object@layers[[i]]) == 'disk') {
+			if (fromDisk(object@layers[[i]])) {
 				object@layers[[i]] <- .clearRaster(object@layers[[i]])
 			}
 		}
 	} else if (class(object) == 'RasterBrick') {
 		object@data@values <- matrix(NA,0,0)
-		object@data@content <- 'nodata'
-		object@data@indices = c(0,0)
-		if (dataSource(object) == 'ram') {
+		object@data@inmemory <- FALSE
+		
+#		object@data@indices = c(0,0)
+		if ( !  fromDisk(object) ) {
 			object@data@min <- rep(Inf, nlayers(object))
 			object@data@max <- rep(-Inf, nlayers(object))
 			object@data@haveminmax <- FALSE
