@@ -9,6 +9,7 @@
 	if (!require(RNetCDF)) { stop('You need to install the RNetCDF package first') }
 
 	nc <- open.nc(filename)
+	on.exit( close.nc(nc) )
 
 	nv <- file.inq.nc(nc)$nvars
     vars <- vector()
@@ -21,20 +22,16 @@
 	dims <- varinfo$ndims
 	
 	if (dims== 1) { 
-		close.nc(nc)
 		stop('zvar only has a single dimension; I cannot make a RasterLayer from this')
 	} else if (dims > 3) { 
-		close.nc(nc)
 		stop(zvar, 'has ', length(dims), ' dimensions, I do not know how to process these data')
 	} else if (dims == 2) {
-		close.nc(nc)
 		return( stack ( raster(filename, x=xvar, y=yvar, varname=zvar )  )  )
 	} else {
 		if (is.null(bands)) { bands <- ''}
 		if (bands[1] == '') {
 			bands = 1 : ( as.integer( dim.inq.nc(nc, var.inq.nc(nc, zvar)$dimids[3])$length ) )
 		}
-		close.nc(nc)
 		st = stack( raster(filename, xvar=x, yvar=y, varname=zvar, band=bands[1]) )
 		if (length(bands) > 1) {
 			for (i in 2:length(bands)) {
